#' A not-too-fast but accurate kNN implementation supporting multiple distance measures
#' 
#' @rdname knn.covertree-package
#' @name knn.covertree
#' 
#' @useDynLib knn.covertree
## Make sure Rcpp and RcppEigen are loaded
#' @importFrom Rcpp evalCpp
#' @importFrom RcppEigen RcppEigen.package.skeleton
"_PACKAGE"
